@@ -1,15 +1,21 @@
 bestset.noise <-
 function (m = 100, n = 40, method = "exhaustive", nvmax = 3,
-              print.summary = TRUE, really.big=FALSE)
+              X=NULL, print.summary = TRUE, really.big=FALSE)
 {
     leaps.out <- try(require(leaps), silent = TRUE)
     if ((is.logical(leaps.out) == TRUE) & (leaps.out == TRUE)) {
+        if(is.null(X)){X <- matrix(rnorm(m * n), ncol = n)
+                       colnames(X) <- paste("V", 1:n, sep = "")
+                   } else
+    {X <- as.matrix(X)
+     m <- dim(X)[1]
+     n <- dim(X)[2]
+     if(is.null(colnames(X)))colnames(X) <- paste("V", 1:n, sep = "")
+ }
         y <- rnorm(m)
-        xx <- matrix(rnorm(m * n), ncol = n)
-        dimnames(xx) <- list(NULL, paste("V", 1:n, sep = ""))
-        u <- regsubsets(xx, y, method = method, nvmax = nvmax,
+        u <- regsubsets(X, y, method = method, nvmax = nvmax,
                         nbest = 1, really.big=really.big)
-        x <- xx[, summary(u)$which[nvmax, -1]]
+        x <- X[, summary(u)$which[nvmax, -1]]
         u1 <- lm(y ~ x)
         if (print.summary)
             print(summary(u1, corr = FALSE))
@@ -19,4 +25,3 @@ function (m = 100, n = 40, method = "exhaustive", nvmax = 3,
         print("Error: package leaps is not installed properly")
     }
 }
-
